# Welcome to pymapee


[![image](https://img.shields.io/pypi/v/pymapee.svg)](https://pypi.python.org/pypi/pymapee)

[![image](https://pyup.io/repos/github/tuyenhavan/pymapee/shield.svg)](https://pyup.io/repos/github/tuyenhavan/pymapee)


**A Simple Python package to pre-processing satellite data using Google Earth Engine.**


-   Free software: MIT license
-   Documentation: <https://tuyenhavan.github.io/pymapee>
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
